/*
 * Copyright 2022 KylinSoft Co., Ltd.
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef MULTITASKVIEWMANAGER_H
#define MULTITASKVIEWMANAGER_H

#include <memory>

#include <QQuickView>

#include <kwineffects.h>

#include "dbusservice.h"
#include "multitaskviewmodel.h"

namespace MultitaskView {

class MultitaskViewManager : public KWin::Effect
{
    Q_OBJECT

public:

    MultitaskViewManager();

    ~MultitaskViewManager() override;

    enum ProjectType {
        PC,
        TABLET,
    };

    void grabbedKeyboardEvent(QKeyEvent* e) override;

    Q_INVOKABLE void open();

    Q_INVOKABLE void close();
    Q_INVOKABLE void showDesktop(bool show);

    Q_INVOKABLE bool useOpenGL() { return useOpenGL_; }

private:

    void initModel();

    void setProjectType();

    void setQmlUrl();

    void registerQmlTypes();

    void registerShortcut();

    void initDBusService();

    void initView();

    void destroyView();

    void connectSignals();

    QString getProjectCodeName();

    QString getOSReleaseValue(const QString key);

    //!
    //! \brief getRotationModeStatus 获取当前旋转模式是否打开
    //!
    bool getRotationModeStatus();

    ///!
    //! \brief setRotationModeStatus
    //!
    void setRotationModeStatus(bool openRotationMode);

private:

    std::unique_ptr<MultitaskViewModel> model_ = nullptr;

    std::unique_ptr<QQuickView> view_ = nullptr;

    std::unique_ptr<DBusService> dbusService_ = nullptr;

    bool isOpen = false;

    bool useOpenGL_ = true;

    ProjectType projectType_ = MultitaskViewManager::PC;

    QUrl qmlUrl_ = QUrl("qrc:/qml/multitaskView.qml");

    //记录旋转模式是否打开
    bool isOpenRotationMode = false;
};

} // namespace MultitaskView

#endif // MULTITASKVIEWMANAGER_H
