/*
 * Copyright 2022 KylinSoft Co., Ltd.
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

import QtQuick 2.12
import QtQuick.Controls 2.5
import QtQuick.Layouts 1.3
import QtQuick.Window 2.12
import QtGraphicalEffects 1.0
import "TabletController.js" as TabletController
import IconTheme 1.0

TabletViewRootWindow {
    id : rootView

    //为了解决控制器模块的view，实现父类调用子类
    signal qmlViewSpaceClicked()
    signal qmlViewClosed()
    signal qmlClearAllAppWindow()
    //由于执行小窗口关闭动效时，会关闭多任务视图多次，导致崩溃，故增加此属性
    property bool alreadyCloseView: false

    Connections{
        target : rootView

        onQmlViewClosed:{
            if (!alreadyCloseView)
            {
                alreadyCloseView = true
                controller.closeMultitaskView()
            }
            if (tabletViewRootModel.count>0)
            {
                tabletViewRootModel.clear()
            }
        }
    }
    Connections{
        target : tabletViewMainWindow
        onQmlAppWindowRemovedForward:{
            for(var i = 0; i < tabletViewRootModel.count; i++){
                var info = tabletViewRootModel.get(i);
                if(info.id === id) {
                    tabletViewRootModel.remove(i);
                    return;
                }
            }
        }
    }

    TabletScrollViewArea {
        id : appArea
        x : 0
        y : Math.floor(scrollViewYStartPoint)
        width : Math.floor(tabletViewMain.width)
        height : Math.floor(scrollViewHeight)
        appModel : tabletViewRootModel
        rootRect : screenRect
    }

    TabletViewClearAllWindowButton {
        id : clearAllWindow
        property var controller : new TabletController.Controller(multitaskViewModel, clearAllWindow, multitaskViewManager, ["none"])
    }

}//Rectangle rootView
